#
# spec file for package lbreakouthd
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lbreakouthd
Version:        1.1.11
Release:        1.1
Summary:        Classic Breakout-Style Game
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Breakout
URL:            https://lgames.sourceforge.net/LBreakoutHD/
Source:         https://sourceforge.net/projects/lgames/files/%{name}/%{name}-%{version}.tar.gz
Source1:        https://sourceforge.net/projects/lgames/files/add-ons/lbreakout2/lbreakout2-levelsets-20160512.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(sdl2)
Requires(post): user(games)

%description
LBreakoutHD is a scaleable 16:9 remake of LBreakout2, a Breakout-style
arcade game for Linux featuring a number of added graphical enhancements
and effects. You control a paddle at the bottom of the playing field
and must destroy bricks at the top by bouncing balls against them.

%prep
%autosetup -p1

%build
%configure \
  --localstatedir=%{_localstatedir}/games
%make_build

%install
%make_install

## install levels
tar -xf %{SOURCE1} -C %{buildroot}%{_datadir}/%{name}/levels

# Remove global hiscores files, not needed since version 1.1.2
rm %{buildroot}%{_localstatedir}/games/*

%find_lang %{name}
%fdupes -s %{buildroot}/%{_datadir}

%files -f %{name}.lang
%license COPYING
%doc Changelog README TODO
%{_bindir}/lbreakouthd
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/apps/lbreakouthd.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Sat May 17 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.11
  Bugfix release
  * The last release was no good: I've disabled the custom cursor
    for now, since it broke stuff like the editor.
  * Also a compile issue with newer C versions should be fixed now
* Sun May 11 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.1.10:
  * Added custom cursor.
  * Added menu option to enable/disable gamepad.
  * Added new levelset Picky by Michael Uplawski.
  * Updated levelset JustGoForIt by anonymous.
- Drop use of deprecated %%suse_update_desktop_file macro.
* Mon Jul 22 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.9
  * install icon according to specification (again)
* Sun May  5 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.8
  * added simplified ball get target algorithm
  * properly install icon
  * fixed another bug in ball reflection
  * properly read windows files in preview and editor
* Sat Apr 13 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.7
  * Re-enabled debug info and potentially fixed some rare bug in
    ball target computation. Also, as a workaround, if the ball
    has an illegal target it returns to the paddle instead of
    getting lost.
  * Fixed mini game Invaders: It unintentionally resembled
    Outbreak. Now, you need to survive each wave by clearing a
    certain number of invaders. The game ends when an Invader
    reaches the paddle.
  * gettext c-format issue fixed.
  * New levelset 'JustGoForIt'.
* Sat Jan 27 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.6
  * unpause only with key p to allow switching windows
  * allow windowed mode if resolution has at least its height
  * added russian translation
  * workaround for possible flickering when setting fullscreen
  * non-blocking wait for key/confirm to workaround SDL bug
  * fixed more typos
- Changes in version 1.1.5
  * added gettext support for yes/no keys
  * added spanish translation
  * fixed comma typos
* Sun Sep 24 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.4
  * bugfix: set correct fullscreen resolution for non-16:9
  * fixed switched shrink/expand extras in editor
  * don't overwrite saved game when testing levels
  * properly fill new window with black
  * show viewport size if used on non-16:9 monitors
* Sat May 13 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.3
  * fixed broken hiscores file check for disabled installation
  * updated config.guess
  * gettext argument set to external since now required
* Sat Mar 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.2
  * mini game "Outbreak" now ends on appearance of 10th brick.
  * show "Game Over" instead of congrats at end of mini game set.
  * fixed memory violation in shine effect.
  * use proper display settings for multiple monitors.
  * properly link to libintl.
  * properly install icons.
  * use config directory as fallback for highscores.
- Drop patch:
  * lbreakouthd-user-hiscoredir.patch (fixed upstream)
* Sun Feb 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update lbreakouthd-user-hiscoredir.patch with upstream version.
* Thu Jan 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add lbreakouthd-user-hiscoredir.patch: Save hiscores to user
  config dir instead of global localstatedir; patch sent upstream
  [https://sourceforge.net/p/lgames/bugs/93/]. This also fixes an
  issue with openSUSE's pkg where the installed hiscores file was
  forced to be have '0664' perms instead of '0666', causing high
  scores to not be saved at all.
- Drop hiscores.hscr file installed to _localstatedir, as it is no
  longer used in light of above patch.
* Sun Jan  1 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.1
  * added keyboard support for menu
  * added test functionality to editor
* Sat Nov 12 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1
  * Added a level editor for LBreakoutHD.
  * Add swedish translation.
* Sat Apr 30 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.0.10:
  * config option for setting directory for user-specific data
  * added french translation
* Sun Mar  6 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.0.9:
  * fixed texture problem with old hardware
* Sat Aug 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.8:
  * The paddle if controlled by keys or game pad now has a slight
    acceleration instead of going to maximum speed instantly as
    before. This makes minor adjustments of the position much
    easier and allows for a pretty nice control of the paddle now.
  * A minor bug in the levelset selection dialog was fixed
  * Cross compiling instructions were improved.
* Sun Apr 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.7:
  * added difficulty "very easy".
  * added gamepad support.
  * added option to restart level.
  * adjusted Kids difficulty.
* Mon Aug  3 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.0.6:
  - fixed crash with 4k resolution (2019/12/27 MS)
- Run spec-cleaner
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Use Source URL for lbreakout2-levelsets-20160512.tar.gz
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.5
